@@ -48,14 +48,14 @@ struct RGBA;
 #define    MATRIX_Y     tab->matrix[7]
 #define    MATRIX_Z     tab->matrix[11]
 
-class KAction;
-class KActionCollection;
-class KToggleAction;
-class KPopupMenu;
-class KRadioAction;
+class TDEAction;
+class TDEActionCollection;
+class TDEToggleAction;
+class TDEPopupMenu;
+class TDERadioAction;
 class KTempFile;
 
-namespace KIO { class Job; }
+namespace TDEIO { class Job; }
 
 class TQTimer;
 class TQPopupMenu;
@@ -124,7 +124,7 @@ class SQ_ToolBar;
 class SQ_GLWidget : public TQGLWidget
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     public:
         SQ_GLWidget(TQWidget *parent = 0, const char *name = 0);
@@ -168,7 +168,7 @@ class SQ_GLWidget : public TQGLWidget
          */
         GLfloat getZoomPercents() const;
 
-        KActionCollection* actionCollection() const;
+        TDEActionCollection* actionCollection() const;
 
         /*
          *  Are we in fullscreen state ?
@@ -332,7 +332,7 @@ class SQ_GLWidget : public TQGLWidget
         void decodeFailedOn0(const int err_code);
 
         /*
-         *  Create KActions.
+         *  Create TDEActions.
          */
         void createActions();
 
@@ -475,7 +475,7 @@ class SQ_GLWidget : public TQGLWidget
         void slotChangeTab(int);
         void slotCloseRequest(int);
 
-        void slotCopyJobResult(KIO::Job *job);
+        void slotCopyJobResult(TDEIO::Job *job);
 
         /*
          *  Slots for toolbar's actions:
@@ -516,11 +516,11 @@ class SQ_GLWidget : public TQGLWidget
         void slotBCG(SQ_ImageBCGOptions *);
         void slotFilter(SQ_ImageFilterOptions *fltopt);
 
-        void slotCopyResult(KIO::Job *);
+        void slotCopyResult(TDEIO::Job *);
 
     private:
-        KAction               *pASelectionClear;
-        KToggleAction         *pAFull, *pAIfLess, *pAZoomW,
+        TDEAction               *pASelectionClear;
+        TDEToggleAction         *pAFull, *pAIfLess, *pAZoomW,
                               *pAZoomH, *pAZoomWH, *pAZoom100,
                               *pAZoomLast,
                               *pASelectionEllipse, *pASelectionRect;
@@ -528,14 +528,14 @@ class SQ_GLWidget : public TQGLWidget
         SQ_ToolButton         *pAToolQuick, *pAToolFull, *pAToolProp, *pAToolPrint;
         SQ_ToolButtonPopup    *pAToolZoom,  *pAToolImages;
 
-        KActionCollection     *ac, *acMain;
+        TDEActionCollection     *ac, *acMain;
         TQPopupMenu            *menu, *menuFile, *menuImage;
         int                             id_saveas, id_settings,
                                         id_f5, id_f6, id_f7, id_f8, id_del,
                                         id_prop;
 
         // popup menu with zoom types (fit width, fit height, zoom 100%...)
-        KPopupMenu            *zoomMenu, *selectionMenu,
+        TDEPopupMenu            *zoomMenu, *selectionMenu,
 
                                   // popup menu with image pages
                                   *images;
@@ -594,7 +594,7 @@ bool SQ_GLWidget::isnice()
 }
 
 inline
-KActionCollection* SQ_GLWidget::actionCollection() const
+TDEActionCollection* SQ_GLWidget::actionCollection() const
 {
     return ac;
 }
